@@ -59,24 +59,21 @@ def handle_execution_date_args(dt: str):
     return datetime.strptime("".join(dt.rsplit(":", 1)), "%Y-%m-%dT%H:%M:%S%z")
 
 
-def handle_input_api(env,read_params, ng_prefix = "ngcash"):
-        layer = read_params["layer"]
-        object_path = read_params["object_path"]
-        partition = read_params["partition"]
-        file_type = read_params["file_type"]
-        input_dict =  {
-            "env": env,
-            "bucket_name": f"{ng_prefix}-datalake-{env}-{layer}",
-            "object_path": object_path,
-            "partition": partition,
-            "file_type": file_type,
+def handle_input_api(env, read_params, ng_prefix="ng"):
+    layer = read_params["layer"]
+    object_path = read_params["object_path"]
+    partition = read_params["partition"]
+    file_type = read_params["file_type"]
+    input_dict = {
+        "env": env,
+        "bucket_name": f"{ng_prefix}-datalake-{layer}-{env}",
+        "object_path": object_path,
+        "partition": partition,
+        "file_type": file_type,
+    }
+    if read_params.get("schema_path") is not None:
+        input_dict["schema_path"] = {
+            "bucket_name": f"{ng_prefix}-repository-{env}",
+            "object_path": read_params["schema_path"],
         }
-        if read_params.get('schema_path') is not None:
-            input_dict['schema_path'] = {
-            "bucket_name": f"{ng_prefix}-datalake-{env}-repository",
-            "object_path": read_params['schema_path']
-        }
-        return input_dict
-
-
-
+    return input_dict
